@@ -28,8 +28,7 @@ from .helpers import\
     random_location,\
     random_timestamp, \
     replace_variables_in_string, \
-    GeoCoderResponse, \
-    JsonAPIClient
+    GeoCoderResponse
 
 from .mocked_rpc_responses import \
     mocked_rpc_response, \
